// ? should support non english characters but won't mess up the url
const nameRestrictions: genericValidation = {
	length: { min: 3, max: 20 },
	regex: /^[\p{L}\p{N}._-]+$/u,
};

function isValidUsername(rawUsername: string): validationResult {
	const username = rawUsername.trim().normalize("NFC");

	if (!username) return { valid: false, error: "Username is required" };

	if (username.length < nameRestrictions.length.min)
		return { valid: false, error: "Username is too short" };

	if (username.length > nameRestrictions.length.max)
		return { valid: false, error: "Username is too long" };

	if (!nameRestrictions.regex.test(username))
		return { valid: false, error: "Username contains invalid characters" };

	if (/^[._-]|[._-]$/.test(username))
		return {
			valid: false,
			error: "Username can't start or end with special characters",
		};

	return { valid: true, username };
}

export { nameRestrictions, isValidUsername };
