import { jsonResponse } from "@lib/http";
import { sessionManager } from "@lib/jwt";
import { redis } from "bun";

const routeDef: RouteDef = {
	method: "DELETE",
	accepts: "*/*",
	returns: "application/json;charset=utf-8",
};

async function handler(request: ExtendedRequest): Promise<Response> {
	const { id: sessionId, all } = request.query;

	if ((all === "true" || all === "1") && request.session) {
		const keys = await redis.keys(`session:${request.session.id}:*`);
		for (const key of keys) {
			await redis.del(key);
		}

		return new Response(null, {
			status: 204,
			headers: {
				"Set-Cookie":
					"session=; Max-Age=0; Path=/; HttpOnly; Secure; SameSite=Strict",
			},
		});
	}

	if (sessionId && typeof sessionId === "string") {
		const keys = await redis.keys(`session:*:${sessionId}`);
		if (!keys.length) {
			return jsonResponse(404, {
				message: "Session not found",
				error: "No session exists with the given ID",
			});
		}
		await redis.del(keys[0]);

		return jsonResponse(200, {
			message: "Session invalidated",
		});
	}

	await sessionManager.invalidateSession(request);

	return new Response(null, {
		status: 204,
		headers: {
			"Set-Cookie":
				"session=; Max-Age=0; Path=/; HttpOnly; Secure; SameSite=Strict",
		},
	});
}

export { handler, routeDef };
